==> cdktf-0.9.0.dev6.tar.gz: package/lib/backends/oss-backend.d.ts <==
import { Construct } from "constructs";
import { TerraformBackend } from "../terraform-backend";
import { TerraformRemoteState, DataTerraformRemoteStateConfig } from "../terraform-remote-state";
/**
 * @experimental
 */
export declare class OssBackend extends TerraformBackend {
    private readonly props;
    /**
     * @experimental
     */
    constructor(scope: Construct, props: OssBackendProps);
    /**
     * @experimental
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
/**
 * @experimental
 */
export declare class DataTerraformRemoteStateOss extends TerraformRemoteState {
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, config: DataTerraformRemoteStateOssConfig);
}
/**
 * @experimental
 */
export interface OssBackendProps {
    /**
     * @experimental
     */
    readonly accessKey?: string;
    /**
     * @experimental
     */
    readonly secretKey?: string;
    /**
     * @experimental
     */
    readonly securityToken?: string;
    /**
     * @experimental
     */
    readonly ecsRoleName?: string;
    /**
     * @experimental
     */
    readonly region?: string;
    /**
     * @experimental
     */
    readonly endpoint?: string;
    /**
     * @experimental
     */
    readonly bucket: string;
    /**
     * @experimental
     */
    readonly prefix?: string;
    /**
     * @experimental
     */
    readonly key?: string;
    /**
     * @experimental
     */
    readonly tablestoreEndpoint?: string;
    /**
     * @experimental
     */
    readonly tablestoreTable?: string;
    /**
     * @experimental
     */
    readonly encrypt?: boolean;
    /**
     * @experimental
     */
    readonly acl?: string;
    /**
     * @experimental
     */
    readonly sharedCredentialsFile?: string;
    /**
     * @experimental
     */
    readonly profile?: string;
    /**
     * @experimental
     */
    readonly assumeRole?: OssAssumeRole;
}
/**
 * @experimental
 */
export interface OssAssumeRole {
    /**
     * @experimental
     */
    readonly roleArn: string;
    /**
     * @experimental
     */
    readonly policy?: string;
    /**
     * @experimental
     */
    readonly sessionName?: string;
    /**
     * @experimental
     */
    readonly sessionExpiration?: number;
}
/**
 * @experimental
 */
export interface DataTerraformRemoteStateOssConfig extends DataTerraformRemoteStateConfig, OssBackendProps {
}

==> cdktf-0.11.0.dev4.tar.gz: package/lib/backends/oss-backend.d.ts <==
import { Construct } from "constructs";
import { TerraformBackend } from "../terraform-backend";
import { TerraformRemoteState, DataTerraformRemoteStateConfig } from "../terraform-remote-state";
export declare class OssBackend extends TerraformBackend {
    private readonly props;
    constructor(scope: Construct, props: OssBackendProps);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    getRemoteStateDataSource(scope: Construct, name: string, _fromStack: string): TerraformRemoteState;
}
export declare class DataTerraformRemoteStateOss extends TerraformRemoteState {
    constructor(scope: Construct, id: string, config: DataTerraformRemoteStateOssConfig);
}
export interface OssBackendProps {
    readonly accessKey?: string;
    readonly secretKey?: string;
    readonly securityToken?: string;
    readonly ecsRoleName?: string;
    readonly region?: string;
    readonly endpoint?: string;
    readonly bucket: string;
    readonly prefix?: string;
    readonly key?: string;
    readonly tablestoreEndpoint?: string;
    readonly tablestoreTable?: string;
    readonly encrypt?: boolean;
    readonly acl?: string;
    readonly sharedCredentialsFile?: string;
    readonly profile?: string;
    readonly assumeRole?: OssAssumeRole;
}
export interface OssAssumeRole {
    readonly roleArn: string;
    readonly policy?: string;
    readonly sessionName?: string;
    readonly sessionExpiration?: number;
}
export interface DataTerraformRemoteStateOssConfig extends DataTerraformRemoteStateConfig, OssBackendProps {
}
